resolve

Function resolve 

pub fn resolve(cwd: &Path) -> Result<Option<Workspace>>
Walk up from cwd to find the nearest Cargo project.

Errors

Returns Error::Io if a manifest cannot be read or Error::TomlParse if it does not parse.